==> plom-0.14.7.tar.gz: plom-0.14.7/README.md <==
# Paperless Open Marking - [Plom](https://plomgrading.org)

  * Plom is a system for large-scale marking by humans of handwritten work.
  * Designed for giving consistent, meaningful feedback to students.
  * [Free/Open Source Software](https://www.gnu.org/licenses/agpl-3.0.en.html)
    written in Python using [Qt](https://pypi.org/project/PyQt6) and other
    components.

<img src="https://plomgrading.org/images/plomclient.png" width="800px" alt="The plom annotation client in action">


## Plom's benefits

  * Respects privacy of student data -- all data stays on your server,
    and markers do not see student name or ID when working.
  * Easy multi-versioned tests -- designed to handle crowded classrooms
    and multi-section courses over multiple days.
  * Simplify logistics and minimizes paper-handling.
  * Free -- Plom is [Libre](https://en.wikipedia.org/wiki/Gratis_versus_libre#Libre)
    and [Gratis](https://en.wikipedia.org/wiki/Gratis_versus_libre#Gratis).
    No software to buy, and no subscriptions to pay.


## Want to know more?

Take a look at the [plomgrading.org](https://plomgrading.org).


## Translations

If you'd like to help translate Plom into another language,
please help at https://gitlab.com/plom/plom/-/issues/1725

The metainfo files (used for example on
[Flathub](https://flathub.org/apps/details/org.plomgrading.PlomClient))
can be translated by editing
[here](https://gitlab.com/plom/plom/-/blob/main/org.plomgrading.PlomClient.metainfo.xml)
and
[here](https://gitlab.com/plom/plom/-/blob/main/org.plomgrading.PlomClient.desktop).



## Getting in touch

  * Our dev channel is [gitter.im/plomgrading/dev](https://gitter.im/plomgrading/dev).
  * Our [main development repo is on Gitlab.com](https://gitlab.com/plom/plom)
    and [mirrored on GitHub](https://github.com/plomgrading/plom).

==> plom-0.16.10.tar.gz: plom-0.16.10/README.md <==
# Paperless Open Marking - [Plom](https://plomgrading.org)

  * Plom is a system for large-scale marking by humans of handwritten work.
  * Designed for giving consistent, meaningful feedback to students.
  * [Free/Open Source Software](https://www.gnu.org/licenses/agpl-3.0.en.html)
    written in Python using [Qt](https://pypi.org/project/PyQt6) and other
    components.

<img src="https://plomgrading.org/images/plomclient.png" width="800px" alt="The plom annotation client in action">


## Plom's benefits

  * Respects privacy of student data -- all data stays on your server,
    and markers do not see student name or ID when working.
  * Easy multi-versioned tests -- designed to handle crowded classrooms
    and multi-section courses over multiple days.
  * Simplify logistics and minimizes paper-handling.
  * Free -- Plom is [Libre](https://en.wikipedia.org/wiki/Gratis_versus_libre#Libre)
    and [Gratis](https://en.wikipedia.org/wiki/Gratis_versus_libre#Gratis).
    No software to buy, and no subscriptions to pay.


## Want to know more?

Take a look at the [plomgrading.org](https://plomgrading.org).


## Translations

If you'd like to help translate Plom into another language,
please help at https://gitlab.com/plom/plom/-/issues/1725

The metainfo files (used for example on
[Flathub](https://flathub.org/apps/org.plomgrading.PlomClient))
can be translated by editing
[here](https://gitlab.com/plom/plom/-/blob/main/org.plomgrading.PlomClient.metainfo.xml)
and
[here](https://gitlab.com/plom/plom/-/blob/main/org.plomgrading.PlomClient.desktop).



## Getting in touch

  * Our dev channel is [gitter.im/plomgrading/dev](https://gitter.im/plomgrading/dev).
  * Our [main development repo is on Gitlab.com](https://gitlab.com/plom/plom)
    and [mirrored on GitHub](https://github.com/plomgrading/plom).
